@@ -20,84 +20,38 @@
 |![Typescript Logo](https://docs.aws.amazon.com/cdk/api/latest/img/typescript32.png) Typescript|`@aws-solutions-constructs/aws-eventbridge-lambda`|
 |![Java Logo](https://docs.aws.amazon.com/cdk/api/latest/img/java32.png) Java|`software.amazon.awsconstructs.services.eventbridgelambda`|
 
-## Overview
-
 This AWS Solutions Construct implements an AWS EventBridge rule and an AWS Lambda function.
 
-Here is a minimal deployable pattern definition:
+Here is a minimal deployable pattern definition in Typescript:
 
-Typescript
+```javascript
+const { EventbridgeToLambdaProps, EventbridgeToLambda } from '@aws-solutions-constructs/aws-eventbridge-lambda';
 
-```python
-import { Construct } from 'constructs';
-import { Stack, StackProps, Duration } from 'aws-cdk-lib';
-import { EventbridgeToLambdaProps, EventbridgeToLambda } from '@aws-solutions-constructs/aws-eventbridge-lambda';
-import * as lambda from 'aws-cdk-lib/aws-lambda';
-import * as events from 'aws-cdk-lib/aws-events';
-
-const constructProps: EventbridgeToLambdaProps = {
-  lambdaFunctionProps: {
-    code: lambda.Code.fromAsset(`lambda`),
-    runtime: lambda.Runtime.NODEJS_14_X,
-    handler: 'index.handler'
-  },
-  eventRuleProps: {
-    schedule: events.Schedule.rate(Duration.minutes(5))
-  }
+const props: EventbridgeToLambdaProps = {
+    lambdaFunctionProps: {
+        code: lambda.Code.fromAsset(`${__dirname}/lambda`),
+        runtime: lambda.Runtime.NODEJS_14_X,
+        handler: 'index.handler'
+    },
+    eventRuleProps: {
+      schedule: events.Schedule.rate(Duration.minutes(5))
+    }
 };
 
-new EventbridgeToLambda(this, 'test-eventbridge-lambda', constructProps);
+new EventbridgeToLambda(this, 'test-eventbridge-lambda', props);
 ```
 
-Python
+## Initializer
 
-```python
-from aws_solutions_constructs.aws_eventbridge_lambda import EventbridgeToLambda, EventbridgeToLambdaProps
-from aws_cdk import (
-    aws_lambda as _lambda,
-    aws_events as events,
-    Duration,
-    Stack
-)
-from constructs import Construct
-
-EventbridgeToLambda(self, 'test-eventbridge-lambda',
-                    lambda_function_props=_lambda.FunctionProps(
-                        code=_lambda.Code.from_asset('lambda'),
-                        runtime=_lambda.Runtime.PYTHON_3_9,
-                        handler='index.handler'
-                    ),
-                    event_rule_props=events.RuleProps(
-                        schedule=events.Schedule.rate(
-                            Duration.minutes(5))
-                    ))
+```text
+new EventbridgeToLambda(scope: Construct, id: string, props: EventbridgeToLambdaProps);
 ```
 
-Java
+*Parameters*
 
-```java
-import software.constructs.Construct;
-
-import software.amazon.awscdk.Stack;
-import software.amazon.awscdk.StackProps;
-import software.amazon.awscdk.Duration;
-import software.amazon.awscdk.services.events.*;
-import software.amazon.awscdk.services.lambda.*;
-import software.amazon.awscdk.services.lambda.Runtime;
-import software.amazon.awsconstructs.services.eventbridgelambda.*;
-
-new EventbridgeToLambda(this, "test-eventbridge-lambda",
-        new EventbridgeToLambdaProps.Builder()
-                .lambdaFunctionProps(new FunctionProps.Builder()
-                        .runtime(Runtime.NODEJS_14_X)
-                        .code(Code.fromAsset("lambda"))
-                        .handler("index.handler")
-                        .build())
-                .eventRuleProps(new RuleProps.Builder()
-                        .schedule(Schedule.rate(Duration.minutes(5)))
-                        .build())
-                .build());
-```
+* scope [`Construct`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_core.Construct.html)
+* id `string`
+* props [`EventbridgeToLambdaProps`](#pattern-construct-props)
 
 ## Pattern Construct Props
 
@@ -140,7 +94,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -152,30 +106,28 @@ import jsii
 import publication
 import typing_extensions
 
-from typeguard import check_type
-
 from ._jsii import *
 
 import aws_cdk.aws_events
 import aws_cdk.aws_lambda
-import aws_cdk.core
+import constructs
 
 
 class EventbridgeToLambda(
-    aws_cdk.core.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-eventbridge-lambda.EventbridgeToLambda",
 ):
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
-        event_rule_props: typing.Union[aws_cdk.aws_events.RuleProps, typing.Dict[str, typing.Any]],
-        event_bus_props: typing.Optional[typing.Union[aws_cdk.aws_events.EventBusProps, typing.Dict[str, typing.Any]]] = None,
+        event_rule_props: aws_cdk.aws_events.RuleProps,
+        event_bus_props: typing.Optional[aws_cdk.aws_events.EventBusProps] = None,
         existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
+        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -189,10 +141,6 @@ class EventbridgeToLambda(
         :access: public
         :summary: Constructs a new instance of the EventbridgeToLambda class.
         '''
-        if __debug__:
-            type_hints = typing.get_type_hints(EventbridgeToLambda.__init__)
-            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
-            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = EventbridgeToLambdaProps(
             event_rule_props=event_rule_props,
             event_bus_props=event_bus_props,
@@ -203,17 +151,17 @@ class EventbridgeToLambda(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="eventsRule")
     def events_rule(self) -> aws_cdk.aws_events.Rule:
         return typing.cast(aws_cdk.aws_events.Rule, jsii.get(self, "eventsRule"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="lambdaFunction")
     def lambda_function(self) -> aws_cdk.aws_lambda.Function:
         return typing.cast(aws_cdk.aws_lambda.Function, jsii.get(self, "lambdaFunction"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="eventBus")
     def event_bus(self) -> typing.Optional[aws_cdk.aws_events.IEventBus]:
         return typing.cast(typing.Optional[aws_cdk.aws_events.IEventBus], jsii.get(self, "eventBus"))
@@ -234,11 +182,11 @@ class EventbridgeToLambdaProps:
     def __init__(
         self,
         *,
-        event_rule_props: typing.Union[aws_cdk.aws_events.RuleProps, typing.Dict[str, typing.Any]],
-        event_bus_props: typing.Optional[typing.Union[aws_cdk.aws_events.EventBusProps, typing.Dict[str, typing.Any]]] = None,
+        event_rule_props: aws_cdk.aws_events.RuleProps,
+        event_bus_props: typing.Optional[aws_cdk.aws_events.EventBusProps] = None,
         existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
+        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
     ) -> None:
         '''
         :param event_rule_props: User provided eventRuleProps to override the defaults. Default: - None
@@ -250,18 +198,11 @@ class EventbridgeToLambdaProps:
         :summary: The properties for the CloudFrontToApiGateway Construct
         '''
         if isinstance(event_rule_props, dict):
-            event_rule_props = RuleProps(**event_rule_props)
+            event_rule_props = aws_cdk.aws_events.RuleProps(**event_rule_props)
         if isinstance(event_bus_props, dict):
-            event_bus_props = EventBusProps(**event_bus_props)
+            event_bus_props = aws_cdk.aws_events.EventBusProps(**event_bus_props)
         if isinstance(lambda_function_props, dict):
-            lambda_function_props = FunctionProps(**lambda_function_props)
-        if __debug__:
-            type_hints = typing.get_type_hints(EventbridgeToLambdaProps.__init__)
-            check_type(argname="argument event_rule_props", value=event_rule_props, expected_type=type_hints["event_rule_props"])
-            check_type(argname="argument event_bus_props", value=event_bus_props, expected_type=type_hints["event_bus_props"])
-            check_type(argname="argument existing_event_bus_interface", value=existing_event_bus_interface, expected_type=type_hints["existing_event_bus_interface"])
-            check_type(argname="argument existing_lambda_obj", value=existing_lambda_obj, expected_type=type_hints["existing_lambda_obj"])
-            check_type(argname="argument lambda_function_props", value=lambda_function_props, expected_type=type_hints["lambda_function_props"])
+            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
         self._values: typing.Dict[str, typing.Any] = {
             "event_rule_props": event_rule_props,
         }
